@@ -6,7 +6,7 @@ manually by calling self.applyData(object, data).
 
   >>> getRootFolder()["manfred"] = Mammoth()
 
-  >>> from zope.testbrowser.testing import Browser
+  >>> from zope.app.wsgi.testlayer import Browser
   >>> browser = Browser()
   >>> browser.handleErrors = False
   >>> browser.open("http://localhost/manfred/@@edit")
